summaryrefslogtreecommitdiff
path: root/lisp/play/yow.el
diff options
context:
space:
mode:
authorRichard M. Stallman <rms@gnu.org>1993-06-01 04:28:54 +0000
committerRichard M. Stallman <rms@gnu.org>1993-06-01 04:28:54 +0000
commit06ba6a036cda8e6a1d8f1ab3fdd06bdf049a5376 (patch)
tree9944c98b0e4211e83cee649d16e78d64531e5e66 /lisp/play/yow.el
parentedc8a226fba69182e8e8b8dddf2b2d8a0b5bfb3f (diff)
downloademacs-06ba6a036cda8e6a1d8f1ab3fdd06bdf049a5376.tar.gz
Use cookie1.el.
Diffstat (limited to 'lisp/play/yow.el')
-rw-r--r--lisp/play/yow.el4
1 files changed, 2 insertions, 2 deletions
diff --git a/lisp/play/yow.el b/lisp/play/yow.el
index 94713ceac2d..f056ec5c6bf 100644
--- a/lisp/play/yow.el
+++ b/lisp/play/yow.el
@@ -25,13 +25,13 @@
;; Important pinheaddery for GNU Emacs.
;;
;; See cookie.el for implementation. Note --- the `n' argument of yow
;; from the 18.xx implementation is no longer; we only support *random*
;; random access now.
;;; Code:
-(require 'cookie)
+(require 'cookie1)
(defvar yow-file (concat data-directory "yow.lines")
"Pertinent pinhead phrases.")
@@ -25,13 +25,13 @@
;; Important pinheaddery for GNU Emacs.
;;
-;; See cookie.el for implementation. Note --- the `n' argument of yow
+;; See cookie1.el for implementation. Note --- the `n' argument of yow
;; from the 18.xx implementation is no longer; we only support *random*
;; random access now.